Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r79752 - trunk/tools/build/v2/test
From: jurko.gospodnetic_at_[hidden]
Date: 2012-07-26 03:33:09


Author: jurko
Date: 2012-07-26 03:33:08 EDT (Thu, 26 Jul 2012)
New Revision: 79752
URL: http://svn.boost.org/trac/boost/changeset/79752

Log:
Internal Boost Build testing system cleanup - minor stylistic changes.
Text files modified:
   trunk/tools/build/v2/test/BoostBuild.py | 16 +++++++++-------
   1 files changed, 9 insertions(+), 7 deletions(-)

Modified: trunk/tools/build/v2/test/BoostBuild.py
==============================================================================
--- trunk/tools/build/v2/test/BoostBuild.py (original)
+++ trunk/tools/build/v2/test/BoostBuild.py 2012-07-26 03:33:08 EDT (Thu, 26 Jul 2012)
@@ -912,8 +912,9 @@
         """
           Wait until newly assigned file system timestamps are large enough to
         be correctly recognized as newer than the given original timestamp.
- This must be recognizable by both this Python based testing framework
- and the Boost Jam executable we are testing.
+ They need to be large enough for this to be recognizable by both this
+ Python based testing framework and the Boost Jam executable being
+ tested.
 
           Note: This code assumes that both the file system and the Boost Jam
         executable being tested use file modification timestamp resolution no
@@ -943,13 +944,14 @@
         """
           Wait until newly assigned file system timestamps are large enough to
         be correctly recognized as newer than the ones assigned to files
- created by our previous build run. This must be recognizable by both
- this Python based testing framework and the Boost Jam executable we are
- testing. Used to make subsequent builds correctly recognize newly
- created or touched files.
+ created by our previous build run. They need to be large enough for
+ this to be recognizable by both this Python based testing framework and
+ the Boost Jam executable being tested. Used to make subsequent builds
+ correctly recognize newly created or touched files.
 
         """
- self.wait_for_time_change(self.last_build_timestamp)
+ if self.last_build_timestamp:
+ self.wait_for_time_change(self.last_build_timestamp)
 
     def __get_current_file_timestamp(self):
         fd, path = tempfile.mkstemp(prefix="__Boost_Build_timestamp_tester__")


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk